#ifndef _DEBUG_H_
#define _DEBUG_H_

#define MEM_GARBAGE (0xfe)

#include <assert.h>
#define Assert(e) assert(e)     /* Just to be the save everywhere            */

#if DEBUG > 0

#include <stdio.h>
void DebugInit(FILE *f);
void DebugPrintf(const char *s, ...);
void AssertPrintf(const char *file, int line, const char *s, ...);

/* All assertion functions jump here, you can put a breakpoint here. */
void AssertFailed(const char *s, int line);

#endif /* DEBUG > 0 */



#if DEBUG > 0
#define Trap(t)          ((t)?AssertFailed(__FILE__,__LINE__):)
#define TrapNot(t)       ((t)?:AssertFailed(__FILE__,__LINE__))
#define PathTest         AssertPrintf(__FILE__,__LINE__,"PathTest\n")
#define PathTestElse     else PathTest
#else
#define Trap(t)
#define TrapNot(t)
#define PathTest
#define PathTestElse     else
#endif


#if DEBUG > 0
void _AssertStr(const char *f, int l, const char *s);
#define AssertStr(s) _AssertStr(__FILE__, __LINE__, s)
#else
#define AssertStr(s)
#endif /* DEBUG > 0 */

#if DEBUG > 0
void _AssertPrintStr(const char *f, int l, const char *s);
#define AssertPrintStr(s) _AssertPrintStr(__FILE__, __LINE__, s)
#else
#define AssertPrintStr(s)
#endif /* DEBUG > 0 */

#if DEBUG > 0
void _AssertPtr(const char *f, int l, const void *const p);
#define AssertPtr(p) _AssertPtr(__FILE__, __LINE__, p)
#else
#define AssertPtr(p)
#endif /* DEBUG > 0 */


/*****************************************************************************/
/*                                                                           */
/*  Here follow the smblib.c-specific assertions                             */
/*                                                                           */
/*****************************************************************************/

#include "smblib.h"

#if DEBUG > 0
void _AssertConnSpace(const char *f, int l,
                      smb_conn *conn,
                      const char *p,
                      int length);
                      
#define AssertConnSpace(c,p,s) _AssertConnSpace( __FILE__, __LINE__, c,p,s)
#else
#define AssertConnSpace(c,p,s)
#endif /* DEBUG > 0 */


#if DEBUG > 0
void _AssertConn(const char *f, int l, smb_conn *conn);
#define AssertConn(c) _AssertConn(__FILE__, __LINE__, c)
#else
#define AssertConn(c)
#endif /* DEBUG > 0 */



#endif /* _DEBUG_H_ */
