#include "errlog.h"
#include "debug.h"
#include <stdio.h>
#include <unistd.h>
#include <stdarg.h>
#include <ctype.h>

static void (*errorlog) (const char *str);
static int ErrLogLevel;

/*****************************************************************************/
/*                                                                           */
/*  ErrLogInit                                                               */
/*                                                                           */
/*****************************************************************************/
void 
ErrLogInit(void (*errlog)(const char *str), int level)
{
  errorlog = errlog;
  ErrLogLevel = level;
/*
#if DEBUG > 0
  DebugInit(err_log);
#endif
*/
}

#ifdef __GNUC__

/*****************************************************************************/
/*                                                                           */
/*  _ErrLog                                                                  */
/*                                                                           */
/*****************************************************************************/
void
_ErrLog(const char *filename, int line, int level, const char *s, ...)
{
  va_list ap;
  char buf[2048];

  if (level > ErrLogLevel)
    return;
  
  sprintf(buf, "%s:%d: ", filename, line);
 
  va_start(ap, s);
  vsprintf(buf + strlen(buf), s, ap);
  va_end(ap);

  if (errorlog != NULL)
    (*errorlog)(buf);
}
  
#else /* __GNUC__ */

/*****************************************************************************/
/*                                                                           */
/*  ErrLog                                                                   */
/*                                                                           */
/*****************************************************************************/
void
ErrLog(int level, const char *s, ...)
{
  va_list ap;
  char buf[2048];

  if (level > ErrLogLevel) return;
  
  if (errorlog != NULL) {
    va_start(ap, s);
    vsprintf(buf, s, ap);
    va_end(ap);
    (*errorlog)(buf);
  }
}

#endif /* __GNUC__ */
