#ifndef _SMBLIB_H_
#define _SMBLIB_H_

#include <sys/types.h>
#include <netinet/in.h>
#include "fslib.h"
#include "pstr.h"

#define SMB_NAMELEN 13

typedef unsigned char  BYTE;
typedef unsigned short WORD;
typedef unsigned long  DWORD;

typedef WORD sfid_t;

typedef struct {
  int        server;
  BYTE       rcls;
  WORD       err;
  WORD       tid;
  WORD       pid;
  WORD       uid;
  WORD       mid;
  int        max_xmit;          /* this includes the 4 bytes from rfc 1002   */

  umode_t    file_mode;
  umode_t    dir_mode;
  gid_t      gid;
  char       buffer[0];
} smb_conn;

typedef struct {
  sfid_t     fid;
  DWORD      size;
  DWORD      mtime;
  WORD       attrib;
  int        access;            /* 0:r/o, 1:w/o, 2:r/w */
  char       name[SMB_NAMELEN];
} smb_finfo;

typedef struct {
  int        total;
  int        allocblocks;
  int        blocksize;
  int        free;
} smb_servattr;


void
Debug(int, char *, ...);

int
smb2unix_errno(smb_conn *conn);

extern int smb_errno;

smb_conn *
smb_connect(const char *server,
            int port,
            const char *service,
            const char *passwd);

smb_conn *
smb_do_connect(struct sockaddr_in *serv_addr,
               const char *my_name,
               const char *serv_name,
               const char *service,
               const char *passwd);

Status
smb_disconnect(smb_conn *conn);

Status
smb_open(smb_conn *conn, const char *name, smb_finfo *finfo);

Bool
smb_mkdir(smb_conn *conn, const char *name);

Status
smb_mknew(smb_conn *conn, const char *name, smb_finfo *finfo);

Status
smb_close(smb_conn *conn, sfid_t fid, time_t time);

Status
smb_truncate(smb_conn *conn, sfid_t fid, size_t length);

Status 
smb_create(smb_conn *conn, const char *name, smb_finfo *finfo);

Status
smb_read(smb_conn *conn, sfid_t fid, off_t off, void *buf, size_t size,
         size_t *nread);

Status
smb_write(smb_conn *conn, sfid_t fid, off_t off, void *buf, size_t size,
          size_t *written);

Bool
smb_flush(smb_conn *conn, sfid_t fid);

Status
smb_getatr(smb_conn *conn, const char *name, smb_finfo *finfo);

Status
smb_setatr(smb_conn *conn, const char *name, smb_finfo *finfo);

Status
smb_dskattr(smb_conn *conn, smb_servattr *smb_stat);

Status
smb_rmdir(smb_conn *conn, const char *name);

Status
smb_unlink(smb_conn *conn, const char *name);

Status
smb_mv(smb_conn *conn, const char *opath, const char *npath);

Status
smb_do_dir(smb_conn *conn, const char *mask,
           void (*handler)(smb_finfo *finfo, void *data), void *data);

Bool
smb_valid_name(pstr name);

#endif /*_SMBLIB_H_*/
